@@ -1,5 +1,8 @@
 import numpy as np
 import time
+
+from loguru import logger
+
 import hgdl.misc as misc
 import dask.distributed
 from distributed import Client, get_client, secede, rejoin, protocol
@@ -11,14 +14,8 @@ import hgdl.local_methods.bump_function as defl
 
 def run_local(d,optima,x0):
     x_defl,f_defl = optima.get_deflation_points(len(optima.list))
-    x,f,grad_norm,eig,local_success = run_local_optimizer(d,x0,x_defl)
-    if not np.any(local_success) and len(optima.list["x"]) == 0:
-        print("No optima found on first attempt, filling in placeholders...")
-        local_success[:] = True
-    optima.fill_in_optima_list(x,f,grad_norm,eig,local_success)
-    return optima
+    return run_local_optimizer(d,x0,x_defl)
 ###########################################################################
-
 def run_local_optimizer(d,x0,x_defl = []):
     """
     this function runs a deflated local methos for
@@ -43,33 +40,26 @@ def run_local_optimizer(d,x0,x_defl = []):
         worker = d.workers["walkers"][(int(i - ((i // number_of_walkers) * number_of_walkers)))]
         data = {"d":bf,"x0":x0[i],"x_defl":x_defl}
         tasks.append(client.submit(local_method,data,workers = worker))
-        print("HGDL says: local optimizer submitted to worker ", worker," ; method: ", d.local_optimizer," tol: ",d.tolerance, flush = True)
+
     results = client.gather(tasks)
     number_of_walkers = len(tasks)
     x = np.empty((number_of_walkers, dim))
     f = np.empty((number_of_walkers))
-    grad_norm = np.empty((number_of_walkers))
+    Lg = np.empty((number_of_walkers, dim))
     eig = np.empty((number_of_walkers,dim))
     local_success = np.empty((number_of_walkers), dtype = bool)
     for i in range(len(tasks)):
-        x[i],f[i],grad_norm[i],eig[i],local_success[i] = results[i]
+        x[i],f[i],Lg[i],eig[i],local_success[i] = results[i]
         client.cancel(tasks[i])
         for j in range(i):
-            #exchange for function def too_close():
             if np.linalg.norm(np.subtract(x[i],x[j])) < 2.0 * d.radius and local_success[j] == True:
-                print("CAUTION: points converged too close to each other in HGDL; point removed")
+                logger.warning("points converged too close to each other in HGDL; point removed")
                 local_success[j] = False; break
         for j in range(len(x_defl)):
-            if np.linalg.norm(np.subtract(x[i],x_defl[j])) < 2.0 * d.radius\
-            and grad_norm[i] < 1e-5:
-                print("CAUTION: local method converged within 2 x radius of a deflated position in HGDL")
+            if np.linalg.norm(np.subtract(x[i],x_defl[j])) < 2.0 * d.radius and all(Lg[i] < 1e-5):
+                logger.warning("local method converged within 2 x radius of a deflated position in HGDL")
                 local_success[i] = False
-                print("point found: ",x[i]," deflated point: ",x_defl[j])
-                print("gradient at the point: ",grad_norm[i])
-                print("distance between the points: ",np.linalg.norm(np.subtract(x[i],x_defl[j])))
-                print("--")
-    return x, f, grad_norm, eig, local_success
-###########################################################################
+    return x, f, Lg, eig, local_success
 
 def local_method(data, method = "dNewton"):
     from functools import partial
@@ -84,32 +74,38 @@ def local_method(data, method = "dNewton"):
     args = d.args
     method = d.local_optimizer
     #augment grad, hess
-    grad = partial(defl.deflated_grad, grad_func = d.grad, x_defl = x_defl, radius = d.radius)
-    if callable(d.hess):
-        hess = partial(defl.deflated_hess, grad_func = d.grad,
-                       hess_func = d.hess, x_defl = x_defl, radius = d.radius)
+    Lgrad = partial(defl.deflated_grad, grad_func = d.Lgrad, x_defl = x_defl, radius = d.radius)
+    if callable(d.Lhess):
+        Lhess = partial(defl.deflated_hess, grad_func = d.Lgrad,
+                       hess_func = d.Lhess, x_defl = x_defl, radius = d.radius)
     else:
-        hess = d.hess
+        Lhess = d.Lhess
+
     #call local methods
     if method == "dNewton":
-        x,f,g,eig,local_success = DNewton(d.func,grad,hess,bounds,x0,max_iter,tol,*args)
+        x,L,Lg,eig,local_success = DNewton(d.L,Lgrad,Lhess,bounds,x0,max_iter,tol,*args)
+        f = d.func(x,*args)
+
     elif type(method) == str:
-        res = minimize(d.func,x0,args = args,method = method,jac = grad,
-                       bounds = bounds, constraints = d.constr, options = {"disp":False})
+        if d.constr: logger.warning("Deflated constraints are only supported by local optimizer 'DNewton'")
+        res = minimize(d.func, x0, args = args, method = method, jac = Lgrad, hess = Lhess,
+                       bounds = bounds, options = {"disp":False})
         x = res["x"]
         f = res["fun"]
-        g = np.linalg.norm(res["jac"])
-        local_success = res["success"]
         eig = np.ones(x.shape) * np.nan
+        Lg = res["jac"]
+        local_success = res["success"]
+
     elif callable(method):
         res = method(d.func,grad,hess,bounds,x0,*args)
         x = res["x"]
         f = res["fun"]
-        g = np.linalg.norm(res["jac"])
-        local_success = res["success"]
         eig = np.ones(x.shape) * np.nan
+        Lg = res["jac"]
+        local_success = res["success"]
+
+
     else: raise Exception("no local method specified")
-    return x,f,g,eig,local_success
+
+    return x,f,Lg,np.real(eig),local_success
 ###########################################################################
-
-
