@@ -11,9 +11,15 @@ class meta_data:
         self.func = obj.func
         self.grad = obj.grad
         self.hess = obj.hess
+        self.L = obj.L
+        self.Lgrad = obj.Lgrad
+        self.Lhess = obj.Lhess
         self.bounds = obj.bounds
         self.radius = obj.radius
-        self.dim = obj.dim
+        self.dim_x = obj.dim_x
+        self.dim_k = obj.dim_k
+        self.dim = obj.dim_x + self.dim_k
+
         self.local_max_iter = obj.local_max_iter
         self.number_of_walkers = obj.number_of_walkers
         self.num_epochs = obj.num_epochs
